/* revealer.c generated by valac 0.22.0.39-4730, the Vala compiler
 * generated from revealer.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter/clutter.h>
#include <float.h>
#include <math.h>
#include <stdlib.h>
#include <string.h>


#define BOXES_TYPE_REVEALER_LAYOUT (boxes_revealer_layout_get_type ())
#define BOXES_REVEALER_LAYOUT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER_LAYOUT, BoxesRevealerLayout))
#define BOXES_REVEALER_LAYOUT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER_LAYOUT, BoxesRevealerLayoutClass))
#define BOXES_IS_REVEALER_LAYOUT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER_LAYOUT))
#define BOXES_IS_REVEALER_LAYOUT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER_LAYOUT))
#define BOXES_REVEALER_LAYOUT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER_LAYOUT, BoxesRevealerLayoutClass))

typedef struct _BoxesRevealerLayout BoxesRevealerLayout;
typedef struct _BoxesRevealerLayoutClass BoxesRevealerLayoutClass;
typedef struct _BoxesRevealerLayoutPrivate BoxesRevealerLayoutPrivate;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;
typedef struct _BoxesRevealerPrivate BoxesRevealerPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block51Data Block51Data;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block52Data Block52Data;

struct _BoxesRevealerLayout {
	ClutterFixedLayout parent_instance;
	BoxesRevealerLayoutPrivate * priv;
};

struct _BoxesRevealerLayoutClass {
	ClutterFixedLayoutClass parent_class;
};

struct _BoxesRevealerLayoutPrivate {
	gboolean horizontal;
};

struct _BoxesRevealer {
	ClutterActor parent_instance;
	BoxesRevealerPrivate * priv;
	guint duration;
	gboolean resize;
};

struct _BoxesRevealerClass {
	ClutterActorClass parent_class;
};

struct _BoxesRevealerPrivate {
	gboolean horizontal;
	gboolean children_visible;
	gchar* animation_prop;
	gboolean _revealed;
};

struct _Block51Data {
	int _ref_count_;
	BoxesRevealer * self;
	gboolean horizontal;
};

struct _Block52Data {
	int _ref_count_;
	BoxesRevealer * self;
	ClutterActor* child;
};


static gpointer boxes_revealer_layout_parent_class = NULL;
static gpointer boxes_revealer_parent_class = NULL;

GType boxes_revealer_layout_get_type (void) G_GNUC_CONST;
#define BOXES_REVEALER_LAYOUT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_REVEALER_LAYOUT, BoxesRevealerLayoutPrivate))
enum  {
	BOXES_REVEALER_LAYOUT_DUMMY_PROPERTY
};
BoxesRevealerLayout* boxes_revealer_layout_new (gboolean horizontal);
BoxesRevealerLayout* boxes_revealer_layout_construct (GType object_type, gboolean horizontal);
static void boxes_revealer_layout_real_allocate (ClutterLayoutManager* base, ClutterContainer* container, ClutterActorBox* allocation, ClutterAllocationFlags flags);
static void boxes_revealer_layout_finalize (GObject* obj);
GType boxes_revealer_get_type (void) G_GNUC_CONST;
#define BOXES_REVEALER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_REVEALER, BoxesRevealerPrivate))
enum  {
	BOXES_REVEALER_DUMMY_PROPERTY,
	BOXES_REVEALER_REVEALED
};
BoxesRevealer* boxes_revealer_new (gboolean horizontal);
BoxesRevealer* boxes_revealer_construct (GType object_type, gboolean horizontal);
static Block51Data* block51_data_ref (Block51Data* _data51_);
static void block51_data_unref (void * _userdata_);
static void __lambda31_ (Block51Data* _data51_, ClutterActor* child);
static void ___lambda31__clutter_container_actor_added (ClutterContainer* _sender, ClutterActor* actor, gpointer self);
static gfloat boxes_revealer_get_child_size (BoxesRevealer* self, ClutterActor* child);
void boxes_revealer_reveal (BoxesRevealer* self);
static void boxes_revealer_unreveal_child (BoxesRevealer* self, ClutterActor* child);
static Block52Data* block52_data_ref (Block52Data* _data52_);
static void block52_data_unref (void * _userdata_);
static void __lambda32_ (Block52Data* _data52_);
static void ___lambda32__clutter_timeline_stopped (ClutterTimeline* _sender, gboolean is_finished, gpointer self);
void boxes_revealer_unreveal (BoxesRevealer* self);
gboolean boxes_revealer_get_revealed (BoxesRevealer* self);
void boxes_revealer_set_revealed (BoxesRevealer* self, gboolean value);
static void boxes_revealer_finalize (GObject* obj);
static void _vala_boxes_revealer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_revealer_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


BoxesRevealerLayout* boxes_revealer_layout_construct (GType object_type, gboolean horizontal) {
	BoxesRevealerLayout * self = NULL;
	gboolean _tmp0_ = FALSE;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	self = (BoxesRevealerLayout*) g_object_new (object_type, NULL);
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp0_ = horizontal;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	self->priv->horizontal = _tmp0_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	return self;
#line 137 "revealer.c"
}


BoxesRevealerLayout* boxes_revealer_layout_new (gboolean horizontal) {
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	return boxes_revealer_layout_construct (BOXES_TYPE_REVEALER_LAYOUT, horizontal);
#line 144 "revealer.c"
}


static void boxes_revealer_layout_real_allocate (ClutterLayoutManager* base, ClutterContainer* container, ClutterActorBox* allocation, ClutterAllocationFlags flags) {
	BoxesRevealerLayout * self;
	ClutterContainer* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	self = (BoxesRevealerLayout*) base;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_return_if_fail (container != NULL);
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_return_if_fail (allocation != NULL);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp0_ = container;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp1_ = clutter_actor_get_children (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, clutter_actor_get_type ()) ? ((ClutterActor*) _tmp0_) : NULL);
#line 162 "revealer.c"
	{
		GList* child_collection = NULL;
		GList* child_it = NULL;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		child_collection = _tmp1_;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		for (child_it = child_collection; child_it != NULL; child_it = child_it->next) {
#line 170 "revealer.c"
			ClutterActor* child = NULL;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
			child = (ClutterActor*) child_it->data;
#line 174 "revealer.c"
			{
				gfloat width = 0.0F;
				gfloat height = 0.0F;
				gfloat availible_w = 0.0F;
				gfloat availible_h = 0.0F;
				ClutterActor* _tmp2_ = NULL;
				gfloat _tmp3_ = 0.0F;
				gfloat _tmp4_ = 0.0F;
				gfloat _tmp5_ = 0.0F;
				gfloat _tmp6_ = 0.0F;
				ClutterActorBox box = {0};
				gfloat _tmp7_ = 0.0F;
				gfloat _tmp8_ = 0.0F;
				ClutterActorBox _tmp9_ = {0};
				gboolean _tmp10_ = FALSE;
				ClutterActor* _tmp13_ = NULL;
				ClutterActorBox _tmp14_ = {0};
				ClutterAllocationFlags _tmp15_ = 0;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp2_ = child;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				clutter_actor_get_preferred_size (_tmp2_, NULL, NULL, &_tmp3_, &_tmp4_);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				width = _tmp3_;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				height = _tmp4_;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				clutter_actor_box_get_size (allocation, &_tmp5_, &_tmp6_);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				availible_w = _tmp5_;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				availible_h = _tmp6_;
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp7_ = width;
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp8_ = height;
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp9_.x1 = (gfloat) 0;
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp9_.y1 = (gfloat) 0;
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp9_.x2 = _tmp7_;
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp9_.y2 = _tmp8_;
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				box = _tmp9_;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp10_ = self->priv->horizontal;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				if (_tmp10_) {
#line 225 "revealer.c"
					gfloat _tmp11_ = 0.0F;
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
					_tmp11_ = availible_w;
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
					box.x2 = _tmp11_;
#line 231 "revealer.c"
				} else {
					gfloat _tmp12_ = 0.0F;
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
					_tmp12_ = availible_h;
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
					box.y2 = _tmp12_;
#line 238 "revealer.c"
				}
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp13_ = child;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp14_ = box;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp15_ = flags;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				clutter_actor_allocate (_tmp13_, &_tmp14_, _tmp15_);
#line 248 "revealer.c"
			}
		}
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_g_list_free0 (child_collection);
#line 253 "revealer.c"
	}
}


static void boxes_revealer_layout_class_init (BoxesRevealerLayoutClass * klass) {
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	boxes_revealer_layout_parent_class = g_type_class_peek_parent (klass);
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_type_class_add_private (klass, sizeof (BoxesRevealerLayoutPrivate));
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	CLUTTER_LAYOUT_MANAGER_CLASS (klass)->allocate = boxes_revealer_layout_real_allocate;
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_revealer_layout_finalize;
#line 267 "revealer.c"
}


static void boxes_revealer_layout_instance_init (BoxesRevealerLayout * self) {
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	self->priv = BOXES_REVEALER_LAYOUT_GET_PRIVATE (self);
#line 274 "revealer.c"
}


static void boxes_revealer_layout_finalize (GObject* obj) {
	BoxesRevealerLayout * self;
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_REVEALER_LAYOUT, BoxesRevealerLayout);
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	G_OBJECT_CLASS (boxes_revealer_layout_parent_class)->finalize (obj);
#line 284 "revealer.c"
}


GType boxes_revealer_layout_get_type (void) {
	static volatile gsize boxes_revealer_layout_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_revealer_layout_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesRevealerLayoutClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_revealer_layout_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesRevealerLayout), 0, (GInstanceInitFunc) boxes_revealer_layout_instance_init, NULL };
		GType boxes_revealer_layout_type_id;
		boxes_revealer_layout_type_id = g_type_register_static (clutter_fixed_layout_get_type (), "BoxesRevealerLayout", &g_define_type_info, 0);
		g_once_init_leave (&boxes_revealer_layout_type_id__volatile, boxes_revealer_layout_type_id);
	}
	return boxes_revealer_layout_type_id__volatile;
}


static Block51Data* block51_data_ref (Block51Data* _data51_) {
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_atomic_int_inc (&_data51_->_ref_count_);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	return _data51_;
#line 305 "revealer.c"
}


static void block51_data_unref (void * _userdata_) {
	Block51Data* _data51_;
	_data51_ = (Block51Data*) _userdata_;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	if (g_atomic_int_dec_and_test (&_data51_->_ref_count_)) {
#line 314 "revealer.c"
		BoxesRevealer * self;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		self = _data51_->self;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_g_object_unref0 (self);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		g_slice_free (Block51Data, _data51_);
#line 322 "revealer.c"
	}
}


static void __lambda31_ (Block51Data* _data51_, ClutterActor* child) {
	BoxesRevealer * self;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	self = _data51_->self;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_return_if_fail (child != NULL);
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp0_ = _data51_->horizontal;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	if (_tmp0_) {
#line 339 "revealer.c"
		ClutterActor* _tmp1_ = NULL;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_tmp1_ = child;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		clutter_actor_set_x_align (_tmp1_, CLUTTER_ACTOR_ALIGN_FILL);
#line 345 "revealer.c"
	} else {
		ClutterActor* _tmp2_ = NULL;
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_tmp2_ = child;
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		clutter_actor_set_y_align (_tmp2_, CLUTTER_ACTOR_ALIGN_FILL);
#line 352 "revealer.c"
	}
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp3_ = self->priv->children_visible;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	if (_tmp3_) {
#line 358 "revealer.c"
		ClutterActor* _tmp4_ = NULL;
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_tmp4_ = child;
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		clutter_actor_show (_tmp4_);
#line 364 "revealer.c"
	} else {
		ClutterActor* _tmp5_ = NULL;
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_tmp5_ = child;
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		clutter_actor_hide (_tmp5_);
#line 371 "revealer.c"
	}
}


static void ___lambda31__clutter_container_actor_added (ClutterContainer* _sender, ClutterActor* actor, gpointer self) {
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	__lambda31_ (self, actor);
#line 379 "revealer.c"
}


BoxesRevealer* boxes_revealer_construct (GType object_type, gboolean horizontal) {
	BoxesRevealer * self = NULL;
	Block51Data* _data51_;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp5_ = FALSE;
	BoxesRevealerLayout* _tmp6_ = NULL;
	BoxesRevealerLayout* _tmp7_ = NULL;
	gboolean _tmp8_ = FALSE;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_data51_ = g_slice_new0 (Block51Data);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_data51_->_ref_count_ = 1;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp0_ = horizontal;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_data51_->horizontal = _tmp0_;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	self = (BoxesRevealer*) g_object_new (object_type, NULL);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_data51_->self = g_object_ref (self);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp1_ = _data51_->horizontal;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	self->priv->horizontal = _tmp1_;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp2_ = _data51_->horizontal;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	if (_tmp2_) {
#line 413 "revealer.c"
		gchar* _tmp3_ = NULL;
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_tmp3_ = g_strdup ("translation-y");
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_g_free0 (self->priv->animation_prop);
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		self->priv->animation_prop = _tmp3_;
#line 421 "revealer.c"
	} else {
		gchar* _tmp4_ = NULL;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_tmp4_ = g_strdup ("translation-x");
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_g_free0 (self->priv->animation_prop);
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		self->priv->animation_prop = _tmp4_;
#line 430 "revealer.c"
	}
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	clutter_actor_set_clip_to_allocation ((ClutterActor*) self, TRUE);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	self->priv->children_visible = TRUE;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	self->duration = (guint) 250;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp5_ = _data51_->horizontal;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp6_ = boxes_revealer_layout_new (_tmp5_);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_object_ref_sink (_tmp6_);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp7_ = _tmp6_;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	clutter_actor_set_layout_manager ((ClutterActor*) self, (ClutterLayoutManager*) _tmp7_);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_g_object_unref0 (_tmp7_);
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp8_ = _data51_->horizontal;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	if (_tmp8_) {
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		clutter_actor_set_x_expand ((ClutterActor*) self, TRUE);
#line 456 "revealer.c"
	} else {
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		clutter_actor_set_y_expand ((ClutterActor*) self, TRUE);
#line 460 "revealer.c"
	}
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_signal_connect_data ((ClutterContainer*) self, "actor-added", (GCallback) ___lambda31__clutter_container_actor_added, block51_data_ref (_data51_), (GClosureNotify) block51_data_unref, 0);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	block51_data_unref (_data51_);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_data51_ = NULL;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	return self;
#line 470 "revealer.c"
}


BoxesRevealer* boxes_revealer_new (gboolean horizontal) {
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	return boxes_revealer_construct (BOXES_TYPE_REVEALER, horizontal);
#line 477 "revealer.c"
}


static gfloat boxes_revealer_get_child_size (BoxesRevealer* self, ClutterActor* child) {
	gfloat result = 0.0F;
	gboolean _tmp0_ = FALSE;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_return_val_if_fail (self != NULL, 0.0F);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_return_val_if_fail (child != NULL, 0.0F);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp0_ = self->priv->horizontal;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	if (_tmp0_) {
#line 492 "revealer.c"
		gfloat height = 0.0F;
		ClutterActor* _tmp1_ = NULL;
		gfloat _tmp2_ = 0.0F;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_tmp1_ = child;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		clutter_actor_get_preferred_height (_tmp1_, (gfloat) (-1), NULL, &_tmp2_);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		height = _tmp2_;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		result = height;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		return result;
#line 506 "revealer.c"
	} else {
		gfloat width = 0.0F;
		ClutterActor* _tmp3_ = NULL;
		gfloat _tmp4_ = 0.0F;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_tmp3_ = child;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		clutter_actor_get_preferred_width (_tmp3_, (gfloat) (-1), NULL, &_tmp4_);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		width = _tmp4_;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		result = width;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		return result;
#line 521 "revealer.c"
	}
}


void boxes_revealer_reveal (BoxesRevealer* self) {
	gboolean _tmp0_ = FALSE;
	gfloat max = 0.0F;
	GList* _tmp2_ = NULL;
	gboolean _tmp20_ = FALSE;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_return_if_fail (self != NULL);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp0_ = self->resize;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	if (_tmp0_) {
#line 537 "revealer.c"
		gboolean _tmp1_ = FALSE;
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_tmp1_ = self->priv->horizontal;
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		if (_tmp1_) {
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
			clutter_actor_set_height ((ClutterActor*) self, 0.0f);
#line 545 "revealer.c"
		} else {
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
			clutter_actor_set_width ((ClutterActor*) self, 0.0f);
#line 549 "revealer.c"
		}
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	max = 0.0f;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp2_ = clutter_actor_get_children ((ClutterActor*) self);
#line 556 "revealer.c"
	{
		GList* child_collection = NULL;
		GList* child_it = NULL;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		child_collection = _tmp2_;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		for (child_it = child_collection; child_it != NULL; child_it = child_it->next) {
#line 564 "revealer.c"
			ClutterActor* child = NULL;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
			child = (ClutterActor*) child_it->data;
#line 568 "revealer.c"
			{
				gboolean _tmp3_ = FALSE;
				ClutterActor* _tmp13_ = NULL;
				ClutterActor* _tmp14_ = NULL;
				guint _tmp15_ = 0U;
				ClutterActor* _tmp16_ = NULL;
				ClutterActor* _tmp17_ = NULL;
				const gchar* _tmp18_ = NULL;
				ClutterActor* _tmp19_ = NULL;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp3_ = self->priv->children_visible;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				if (!_tmp3_) {
#line 582 "revealer.c"
					ClutterActor* _tmp4_ = NULL;
					gfloat size = 0.0F;
					ClutterActor* _tmp5_ = NULL;
					gfloat _tmp6_ = 0.0F;
					gfloat _tmp7_ = 0.0F;
					gfloat _tmp8_ = 0.0F;
					gfloat _tmp9_ = 0.0F;
					ClutterActor* _tmp10_ = NULL;
					const gchar* _tmp11_ = NULL;
					gfloat _tmp12_ = 0.0F;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
					_tmp4_ = child;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
					clutter_actor_show (_tmp4_);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
					_tmp5_ = child;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
					_tmp6_ = boxes_revealer_get_child_size (self, _tmp5_);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
					size = _tmp6_;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
					_tmp7_ = max;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
					_tmp8_ = size;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
					_tmp9_ = MAX (_tmp7_, _tmp8_);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
					max = _tmp9_;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
					_tmp10_ = child;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
					_tmp11_ = self->priv->animation_prop;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
					_tmp12_ = size;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
					g_object_set ((GObject*) _tmp10_, _tmp11_, -_tmp12_, NULL);
#line 619 "revealer.c"
				}
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp13_ = child;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				clutter_actor_save_easing_state (_tmp13_);
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp14_ = child;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp15_ = self->duration;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				clutter_actor_set_easing_duration (_tmp14_, _tmp15_);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp16_ = child;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				clutter_actor_set_easing_mode (_tmp16_, CLUTTER_EASE_IN_QUAD);
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp17_ = child;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp18_ = self->priv->animation_prop;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				g_object_set ((GObject*) _tmp17_, _tmp18_, 0.0f, NULL);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp19_ = child;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				clutter_actor_restore_easing_state (_tmp19_);
#line 645 "revealer.c"
			}
		}
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_g_list_free0 (child_collection);
#line 650 "revealer.c"
	}
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp20_ = self->resize;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	if (_tmp20_) {
#line 656 "revealer.c"
		guint _tmp21_ = 0U;
		gboolean _tmp22_ = FALSE;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		clutter_actor_save_easing_state ((ClutterActor*) self);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		clutter_actor_set_easing_mode ((ClutterActor*) self, CLUTTER_EASE_IN_QUAD);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_tmp21_ = self->duration;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		clutter_actor_set_easing_duration ((ClutterActor*) self, _tmp21_);
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_tmp22_ = self->priv->horizontal;
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		if (_tmp22_) {
#line 671 "revealer.c"
			gfloat _tmp23_ = 0.0F;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
			_tmp23_ = max;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
			clutter_actor_set_height ((ClutterActor*) self, _tmp23_);
#line 677 "revealer.c"
		} else {
			gfloat _tmp24_ = 0.0F;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
			_tmp24_ = max;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
			clutter_actor_set_width ((ClutterActor*) self, _tmp24_);
#line 684 "revealer.c"
		}
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		clutter_actor_restore_easing_state ((ClutterActor*) self);
#line 688 "revealer.c"
	}
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	self->priv->children_visible = TRUE;
#line 692 "revealer.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	return self ? g_object_ref (self) : NULL;
#line 699 "revealer.c"
}


static Block52Data* block52_data_ref (Block52Data* _data52_) {
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_atomic_int_inc (&_data52_->_ref_count_);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	return _data52_;
#line 708 "revealer.c"
}


static void block52_data_unref (void * _userdata_) {
	Block52Data* _data52_;
	_data52_ = (Block52Data*) _userdata_;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	if (g_atomic_int_dec_and_test (&_data52_->_ref_count_)) {
#line 717 "revealer.c"
		BoxesRevealer * self;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		self = _data52_->self;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_g_object_unref0 (_data52_->child);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_g_object_unref0 (self);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		g_slice_free (Block52Data, _data52_);
#line 727 "revealer.c"
	}
}


static void __lambda32_ (Block52Data* _data52_) {
	BoxesRevealer * self;
	ClutterActor* _tmp0_ = NULL;
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	self = _data52_->self;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp0_ = _data52_->child;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	clutter_actor_hide (_tmp0_);
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	self->priv->children_visible = FALSE;
#line 743 "revealer.c"
}


static void ___lambda32__clutter_timeline_stopped (ClutterTimeline* _sender, gboolean is_finished, gpointer self) {
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	__lambda32_ (self);
#line 750 "revealer.c"
}


static void boxes_revealer_unreveal_child (BoxesRevealer* self, ClutterActor* child) {
	Block52Data* _data52_;
	ClutterActor* _tmp0_ = NULL;
	ClutterActor* _tmp1_ = NULL;
	ClutterActor* _tmp2_ = NULL;
	ClutterActor* _tmp3_ = NULL;
	guint _tmp4_ = 0U;
	ClutterActor* _tmp5_ = NULL;
	ClutterActor* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	ClutterActor* _tmp8_ = NULL;
	gfloat _tmp9_ = 0.0F;
	ClutterActor* _tmp10_ = NULL;
	ClutterActor* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	ClutterTransition* _tmp13_ = NULL;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_return_if_fail (self != NULL);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_return_if_fail (child != NULL);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_data52_ = g_slice_new0 (Block52Data);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_data52_->_ref_count_ = 1;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_data52_->self = g_object_ref (self);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp0_ = child;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_g_object_unref0 (_data52_->child);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_data52_->child = _tmp1_;
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp2_ = _data52_->child;
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	clutter_actor_save_easing_state (_tmp2_);
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp3_ = _data52_->child;
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp4_ = self->duration;
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	clutter_actor_set_easing_duration (_tmp3_, _tmp4_);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp5_ = _data52_->child;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	clutter_actor_set_easing_mode (_tmp5_, CLUTTER_EASE_OUT_QUAD);
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp6_ = _data52_->child;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp7_ = self->priv->animation_prop;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp8_ = _data52_->child;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp9_ = boxes_revealer_get_child_size (self, _tmp8_);
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_object_set ((GObject*) _tmp6_, _tmp7_, -_tmp9_, NULL);
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp10_ = _data52_->child;
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	clutter_actor_restore_easing_state (_tmp10_);
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp11_ = _data52_->child;
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp12_ = self->priv->animation_prop;
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp13_ = clutter_actor_get_transition (_tmp11_, _tmp12_);
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_signal_connect_data ((ClutterTimeline*) _tmp13_, "stopped", (GCallback) ___lambda32__clutter_timeline_stopped, block52_data_ref (_data52_), (GClosureNotify) block52_data_unref, 0);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	block52_data_unref (_data52_);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_data52_ = NULL;
#line 828 "revealer.c"
}


void boxes_revealer_unreveal (BoxesRevealer* self) {
	gboolean _tmp0_ = FALSE;
	gboolean found_child = FALSE;
	GList* _tmp1_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp6_ = FALSE;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_return_if_fail (self != NULL);
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp0_ = self->priv->children_visible;
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	if (!_tmp0_) {
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		return;
#line 846 "revealer.c"
	}
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	found_child = FALSE;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp1_ = clutter_actor_get_children ((ClutterActor*) self);
#line 852 "revealer.c"
	{
		GList* child_collection = NULL;
		GList* child_it = NULL;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		child_collection = _tmp1_;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		for (child_it = child_collection; child_it != NULL; child_it = child_it->next) {
#line 860 "revealer.c"
			ClutterActor* child = NULL;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
			child = (ClutterActor*) child_it->data;
#line 864 "revealer.c"
			{
				ClutterActor* _tmp2_ = NULL;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				found_child = TRUE;
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				_tmp2_ = child;
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
				boxes_revealer_unreveal_child (self, _tmp2_);
#line 873 "revealer.c"
			}
		}
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_g_list_free0 (child_collection);
#line 878 "revealer.c"
	}
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp3_ = self->resize;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	if (_tmp3_) {
#line 884 "revealer.c"
		guint _tmp4_ = 0U;
		gboolean _tmp5_ = FALSE;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		clutter_actor_save_easing_state ((ClutterActor*) self);
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_tmp4_ = self->duration;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		clutter_actor_set_easing_duration ((ClutterActor*) self, _tmp4_);
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		clutter_actor_set_easing_mode ((ClutterActor*) self, CLUTTER_EASE_OUT_QUAD);
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		_tmp5_ = self->priv->horizontal;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		if (_tmp5_) {
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
			clutter_actor_set_height ((ClutterActor*) self, 0.0f);
#line 901 "revealer.c"
		} else {
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
			clutter_actor_set_width ((ClutterActor*) self, 0.0f);
#line 905 "revealer.c"
		}
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		clutter_actor_restore_easing_state ((ClutterActor*) self);
#line 909 "revealer.c"
	}
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp6_ = found_child;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	if (!_tmp6_) {
#line 170 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		self->priv->children_visible = FALSE;
#line 917 "revealer.c"
	}
}


gboolean boxes_revealer_get_revealed (BoxesRevealer* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp0_ = self->priv->_revealed;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	result = _tmp0_;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	return result;
#line 933 "revealer.c"
}


void boxes_revealer_set_revealed (BoxesRevealer* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_return_if_fail (self != NULL);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp0_ = self->priv->_revealed;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp1_ = value;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	if (_tmp0_ == _tmp1_) {
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		return;
#line 952 "revealer.c"
	}
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp2_ = value;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	self->priv->_revealed = _tmp2_;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_tmp3_ = value;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	if (_tmp3_) {
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		boxes_revealer_reveal (self);
#line 964 "revealer.c"
	} else {
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		boxes_revealer_unreveal (self);
#line 968 "revealer.c"
	}
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_object_notify ((GObject *) self, "revealed");
#line 972 "revealer.c"
}


static void boxes_revealer_class_init (BoxesRevealerClass * klass) {
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	boxes_revealer_parent_class = g_type_class_peek_parent (klass);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_type_class_add_private (klass, sizeof (BoxesRevealerPrivate));
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_revealer_get_property;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_revealer_set_property;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_revealer_finalize;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_REVEALER_REVEALED, g_param_spec_boolean ("revealed", "revealed", "revealed", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 989 "revealer.c"
}


static void boxes_revealer_instance_init (BoxesRevealer * self) {
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	self->priv = BOXES_REVEALER_GET_PRIVATE (self);
#line 996 "revealer.c"
}


static void boxes_revealer_finalize (GObject* obj) {
	BoxesRevealer * self;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_REVEALER, BoxesRevealer);
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	_g_free0 (self->priv->animation_prop);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	G_OBJECT_CLASS (boxes_revealer_parent_class)->finalize (obj);
#line 1008 "revealer.c"
}


GType boxes_revealer_get_type (void) {
	static volatile gsize boxes_revealer_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_revealer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesRevealerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_revealer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesRevealer), 0, (GInstanceInitFunc) boxes_revealer_instance_init, NULL };
		GType boxes_revealer_type_id;
		boxes_revealer_type_id = g_type_register_static (clutter_actor_get_type (), "BoxesRevealer", &g_define_type_info, 0);
		g_once_init_leave (&boxes_revealer_type_id__volatile, boxes_revealer_type_id);
	}
	return boxes_revealer_type_id__volatile;
}


static void _vala_boxes_revealer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesRevealer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_REVEALER, BoxesRevealer);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	switch (property_id) {
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		case BOXES_REVEALER_REVEALED:
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		g_value_set_boolean (value, boxes_revealer_get_revealed (self));
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		break;
#line 1035 "revealer.c"
		default:
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		break;
#line 1041 "revealer.c"
	}
}


static void _vala_boxes_revealer_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesRevealer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_REVEALER, BoxesRevealer);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
	switch (property_id) {
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		case BOXES_REVEALER_REVEALED:
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		boxes_revealer_set_revealed (self, g_value_get_boolean (value));
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		break;
#line 1057 "revealer.c"
		default:
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/revealer.vala"
		break;
#line 1063 "revealer.c"
	}
}



